@@ -632,7 +632,8 @@ class SagemakerAnalytics(Magics):
         "--assumable-role-arn",
         type=str,
         default=None,
-        help="The IAM role to assume when connecting to a cluster in a different account.",
+        help="The IAM role to assume when connecting to a cluster in a different AWS account. This argument is not "
+        "required when connecting to a cluster in the same AWS account.",
     )
     def sm_analytics(self, line):
         usage = "Please look at usage of %sm_analytics by executing `%sm_analytics?`."
@@ -693,7 +694,6 @@ def _get_boto3_session(role_arn):
     if not role_arn:
         return boto3.session.Session()
     else:
-        logger.info(f"Assuming role: {role_arn}")
         sts_client = boto3.client("sts")
         try:
             assume_role_object = sts_client.assume_role(
